""" WingDBG product initialization """

try:
    # Prevents deprecation warning in Zope 2.12
    from App.ImageFile import ImageFile
except ImportError:
    from Globals import ImageFile

import Globals
from config import *

from logging import getLogger

logger = getLogger(PACKAGE_NAME)

# define icons; old style because we are not registering any addable types.
misc_ = {
    ICON_NAME: ImageFile('www/icon.gif', globals()),
}

logger.warning('Starting WingDBG Initilization...')
import ControlPanelPatch

def initialize(context):
    """Initialize the WingDBG product."""
    import sys
    import WingDBG
    from ZODB.POSException import ConflictError
    from zLOG import WARNING, ERROR, INFO, LOG

    # Hack our way into the control panel
    cp = context._ProductContext__app.Control_Panel
    if WingDBG.WingDebugService.id not in cp.objectIds():
        wdbgs = WingDBG.WingDebugService()
        cp._setObject(wdbgs.id, wdbgs)
        logger.info('Installed Wing Debug Service in Control Panel')



    wds = cp._getOb(WingDBG.WingDebugService.id)
    if wds.auto_start:
        try:
            wds.startDebugger()
        except ConflictError:
            raise
        except:
            logger.error('Could not start Wing IDE debugger',
                         error=sys.exc_info())
            return

        if wds.connect_at_start:
            try:
                wds.connectIDE(wait=False)
            except ConflictError:
                raise
            except:
                logger.error('Could not connect to IDE', error=sys.exc_info())
                return

            if not wds.isConnected():
                logger.info('IDE connection pending')
            else:
                logger.info('Successfully connected to IDE')

    else:
        logger.info('Wing IDE debugger disable by default')
